# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasource.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import kismet_pb2 as kismet__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datasource.proto',
  package='KismetDatasource',
  syntax='proto2',
  serialized_pb=_b('\n\x10\x64\x61tasource.proto\x12\x10KismetDatasource\x1a\x0ckismet.proto\"\x1f\n\x0bSubChannels\x12\x10\n\x08\x63hannels\x18\x01 \x03(\t\"\x1d\n\nSubChanset\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\t\"c\n\nSubChanhop\x12\x10\n\x08\x63hannels\x18\x01 \x03(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x01\x12\x0f\n\x07shuffle\x18\x03 \x01(\x08\x12\x14\n\x0cshuffle_skip\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\"\xc8\x01\n\x06SubGps\x12\x0b\n\x03lat\x18\x01 \x02(\x01\x12\x0b\n\x03lon\x18\x02 \x02(\x01\x12\x0b\n\x03\x61lt\x18\x03 \x02(\x01\x12\r\n\x05speed\x18\x04 \x02(\x01\x12\x0f\n\x07heading\x18\x05 \x02(\x01\x12\x11\n\tprecision\x18\x06 \x02(\x01\x12\x0b\n\x03\x66ix\x18\x07 \x02(\r\x12\x10\n\x08time_sec\x18\x08 \x02(\x04\x12\x11\n\ttime_usec\x18\t \x02(\x04\x12\x0c\n\x04type\x18\n \x02(\t\x12\x0c\n\x04name\x18\x0b \x02(\t\x12\x16\n\x0ehigh_prec_time\x18\x0c \x01(\x01\"B\n\x0cSubInterface\x12\x11\n\tinterface\x18\x01 \x02(\t\x12\r\n\x05\x66lags\x18\x02 \x02(\t\x12\x10\n\x08hardware\x18\x03 \x01(\t\"Y\n\tSubPacket\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0b\n\x03\x64lt\x18\x03 \x02(\r\x12\x0c\n\x04size\x18\x04 \x02(\x04\x12\x0c\n\x04\x64\x61ta\x18\x05 \x02(\x0c\"J\n\x07SubJson\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0c\n\x04type\x18\x03 \x02(\t\x12\x0c\n\x04json\x18\x04 \x02(\t\"N\n\tSubBuffer\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0c\n\x04type\x18\x03 \x02(\t\x12\x0e\n\x06\x62uffer\x18\x04 \x02(\x0c\"\x90\x01\n\tSubSignal\x12\x12\n\nsignal_dbm\x18\x01 \x01(\x01\x12\x11\n\tnoise_dbm\x18\x02 \x01(\x01\x12\x13\n\x0bsignal_rssi\x18\x03 \x01(\x01\x12\x12\n\nnoise_rssi\x18\x04 \x01(\x01\x12\x10\n\x08\x66req_khz\x18\x05 \x01(\x01\x12\x0f\n\x07\x63hannel\x18\x06 \x01(\t\x12\x10\n\x08\x64\x61tarate\x18\x07 \x01(\x01\"\x9f\x01\n\nSubSpecset\x12\x11\n\tstart_mhz\x18\x01 \x01(\x01\x12\x0f\n\x07\x65nd_mhz\x18\x02 \x01(\x01\x12\x1a\n\x12samples_per_bucket\x18\x03 \x01(\x01\x12\x17\n\x0f\x62ucket_width_hz\x18\x04 \x01(\x01\x12\x12\n\nenable_amp\x18\x05 \x01(\x08\x12\x0e\n\x06if_amp\x18\x06 \x01(\x04\x12\x14\n\x0c\x62\x61seband_amp\x18\x07 \x01(\x04\"}\n\x0bSubSpectrum\x12\x10\n\x08time_sec\x18\x01 \x01(\x04\x12\x11\n\ttime_usec\x18\x02 \x01(\x04\x12\x11\n\tstart_mhz\x18\x03 \x01(\x01\x12\x0f\n\x07\x65nd_mhz\x18\x04 \x01(\x01\x12\x17\n\x0f\x62ucket_width_hz\x18\x05 \x01(\x01\x12\x0c\n\x04\x64\x61ta\x18\x06 \x03(\x05\",\n\nSubSuccess\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\r\n\x05seqno\x18\x02 \x02(\r\"\x11\n\x0f\x43loseDatasource\"\x99\x01\n\tConfigure\x12-\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12-\n\x07hopping\x18\x02 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12.\n\x08spectrum\x18\x03 \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\"\xdf\x01\n\x0f\x43onfigureReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12-\n\x07hopping\x18\x03 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12.\n\x07message\x18\x04 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x0f\n\x07warning\x18\x05 \x01(\t\"\xed\x02\n\nDataReport\x12%\n\x03gps\x18\x01 \x01(\x0b\x32\x18.KismetDatasource.SubGps\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.KismetDatasource.SubPacket\x12+\n\x06signal\x18\x04 \x01(\x0b\x32\x1b.KismetDatasource.SubSignal\x12/\n\x08spectrum\x18\x05 \x01(\x0b\x32\x1d.KismetDatasource.SubSpectrum\x12\x0f\n\x07warning\x18\x06 \x01(\t\x12\'\n\x04json\x18\x07 \x01(\x0b\x32\x19.KismetDatasource.SubJson\x12+\n\x06\x62uffer\x18\x08 \x01(\x0b\x32\x1b.KismetDatasource.SubBuffer\x12\x16\n\x0ehigh_prec_time\x18\t \x01(\x01\"l\n\x0b\x45rrorReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\"\x10\n\x0eListInterfaces\"\xa5\x01\n\x10InterfacesReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x32\n\ninterfaces\x18\x03 \x03(\x0b\x32\x1e.KismetDatasource.SubInterface\"A\n\tNewSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\x12\x12\n\nsourcetype\x18\x02 \x02(\t\x12\x0c\n\x04uuid\x18\x03 \x02(\t\" \n\nOpenSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\"\x8c\x03\n\x10OpenSourceReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12\x0b\n\x03\x64lt\x18\x02 \x01(\r\x12\x19\n\x11\x63\x61pture_interface\x18\x03 \x01(\t\x12/\n\x08\x63hannels\x18\x04 \x01(\x0b\x32\x1d.KismetDatasource.SubChannels\x12-\n\x07\x63hannel\x18\x05 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12\x30\n\nhop_config\x18\x06 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12\x10\n\x08hardware\x18\x07 \x01(\t\x12.\n\x07message\x18\x08 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12.\n\x08spectrum\x18\t \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\x12\x0c\n\x04uuid\x18\n \x01(\t\x12\x0f\n\x07warning\x18\x0b \x01(\t\"!\n\x0bProbeSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\"\x94\x02\n\x11ProbeSourceReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12/\n\x08\x63hannels\x18\x03 \x01(\x0b\x32\x1d.KismetDatasource.SubChannels\x12-\n\x07\x63hannel\x18\x04 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12.\n\x08spectrum\x18\x05 \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\x12\x10\n\x08hardware\x18\x06 \x01(\t\" \n\rWarningReport\x12\x0f\n\x07warning\x18\x01 \x02(\t')
  ,
  dependencies=[kismet__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SUBCHANNELS = _descriptor.Descriptor(
  name='SubChannels',
  full_name='KismetDatasource.SubChannels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.SubChannels.channels', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=83,
)


_SUBCHANSET = _descriptor.Descriptor(
  name='SubChanset',
  full_name='KismetDatasource.SubChanset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.SubChanset.channel', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=114,
)


_SUBCHANHOP = _descriptor.Descriptor(
  name='SubChanhop',
  full_name='KismetDatasource.SubChanhop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.SubChanhop.channels', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='KismetDatasource.SubChanhop.rate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shuffle', full_name='KismetDatasource.SubChanhop.shuffle', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shuffle_skip', full_name='KismetDatasource.SubChanhop.shuffle_skip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='KismetDatasource.SubChanhop.offset', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=215,
)


_SUBGPS = _descriptor.Descriptor(
  name='SubGps',
  full_name='KismetDatasource.SubGps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='KismetDatasource.SubGps.lat', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='KismetDatasource.SubGps.lon', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alt', full_name='KismetDatasource.SubGps.alt', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speed', full_name='KismetDatasource.SubGps.speed', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heading', full_name='KismetDatasource.SubGps.heading', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='precision', full_name='KismetDatasource.SubGps.precision', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fix', full_name='KismetDatasource.SubGps.fix', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubGps.time_sec', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubGps.time_usec', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubGps.type', index=9,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='KismetDatasource.SubGps.name', index=10,
      number=11, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_prec_time', full_name='KismetDatasource.SubGps.high_prec_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=418,
)


_SUBINTERFACE = _descriptor.Descriptor(
  name='SubInterface',
  full_name='KismetDatasource.SubInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface', full_name='KismetDatasource.SubInterface.interface', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='KismetDatasource.SubInterface.flags', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.SubInterface.hardware', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=486,
)


_SUBPACKET = _descriptor.Descriptor(
  name='SubPacket',
  full_name='KismetDatasource.SubPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubPacket.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubPacket.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dlt', full_name='KismetDatasource.SubPacket.dlt', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='KismetDatasource.SubPacket.size', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='KismetDatasource.SubPacket.data', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=577,
)


_SUBJSON = _descriptor.Descriptor(
  name='SubJson',
  full_name='KismetDatasource.SubJson',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubJson.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubJson.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubJson.type', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='json', full_name='KismetDatasource.SubJson.json', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=653,
)


_SUBBUFFER = _descriptor.Descriptor(
  name='SubBuffer',
  full_name='KismetDatasource.SubBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubBuffer.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubBuffer.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubBuffer.type', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='KismetDatasource.SubBuffer.buffer', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=733,
)


_SUBSIGNAL = _descriptor.Descriptor(
  name='SubSignal',
  full_name='KismetDatasource.SubSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signal_dbm', full_name='KismetDatasource.SubSignal.signal_dbm', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='noise_dbm', full_name='KismetDatasource.SubSignal.noise_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal_rssi', full_name='KismetDatasource.SubSignal.signal_rssi', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='noise_rssi', full_name='KismetDatasource.SubSignal.noise_rssi', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freq_khz', full_name='KismetDatasource.SubSignal.freq_khz', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.SubSignal.channel', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='datarate', full_name='KismetDatasource.SubSignal.datarate', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=880,
)


_SUBSPECSET = _descriptor.Descriptor(
  name='SubSpecset',
  full_name='KismetDatasource.SubSpecset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_mhz', full_name='KismetDatasource.SubSpecset.start_mhz', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_mhz', full_name='KismetDatasource.SubSpecset.end_mhz', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='samples_per_bucket', full_name='KismetDatasource.SubSpecset.samples_per_bucket', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket_width_hz', full_name='KismetDatasource.SubSpecset.bucket_width_hz', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable_amp', full_name='KismetDatasource.SubSpecset.enable_amp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='if_amp', full_name='KismetDatasource.SubSpecset.if_amp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='baseband_amp', full_name='KismetDatasource.SubSpecset.baseband_amp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1042,
)


_SUBSPECTRUM = _descriptor.Descriptor(
  name='SubSpectrum',
  full_name='KismetDatasource.SubSpectrum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubSpectrum.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubSpectrum.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_mhz', full_name='KismetDatasource.SubSpectrum.start_mhz', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_mhz', full_name='KismetDatasource.SubSpectrum.end_mhz', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket_width_hz', full_name='KismetDatasource.SubSpectrum.bucket_width_hz', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='KismetDatasource.SubSpectrum.data', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1169,
)


_SUBSUCCESS = _descriptor.Descriptor(
  name='SubSuccess',
  full_name='KismetDatasource.SubSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.SubSuccess.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seqno', full_name='KismetDatasource.SubSuccess.seqno', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1215,
)


_CLOSEDATASOURCE = _descriptor.Descriptor(
  name='CloseDatasource',
  full_name='KismetDatasource.CloseDatasource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1234,
)


_CONFIGURE = _descriptor.Descriptor(
  name='Configure',
  full_name='KismetDatasource.Configure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.Configure.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hopping', full_name='KismetDatasource.Configure.hopping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.Configure.spectrum', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1390,
)


_CONFIGUREREPORT = _descriptor.Descriptor(
  name='ConfigureReport',
  full_name='KismetDatasource.ConfigureReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ConfigureReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.ConfigureReport.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hopping', full_name='KismetDatasource.ConfigureReport.hopping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ConfigureReport.message', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.ConfigureReport.warning', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1616,
)


_DATAREPORT = _descriptor.Descriptor(
  name='DataReport',
  full_name='KismetDatasource.DataReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gps', full_name='KismetDatasource.DataReport.gps', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.DataReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='KismetDatasource.DataReport.packet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='KismetDatasource.DataReport.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.DataReport.spectrum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.DataReport.warning', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='json', full_name='KismetDatasource.DataReport.json', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='KismetDatasource.DataReport.buffer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_prec_time', full_name='KismetDatasource.DataReport.high_prec_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1984,
)


_ERRORREPORT = _descriptor.Descriptor(
  name='ErrorReport',
  full_name='KismetDatasource.ErrorReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ErrorReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ErrorReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2094,
)


_LISTINTERFACES = _descriptor.Descriptor(
  name='ListInterfaces',
  full_name='KismetDatasource.ListInterfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2112,
)


_INTERFACESREPORT = _descriptor.Descriptor(
  name='InterfacesReport',
  full_name='KismetDatasource.InterfacesReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.InterfacesReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.InterfacesReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='KismetDatasource.InterfacesReport.interfaces', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2280,
)


_NEWSOURCE = _descriptor.Descriptor(
  name='NewSource',
  full_name='KismetDatasource.NewSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.NewSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sourcetype', full_name='KismetDatasource.NewSource.sourcetype', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KismetDatasource.NewSource.uuid', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2347,
)


_OPENSOURCE = _descriptor.Descriptor(
  name='OpenSource',
  full_name='KismetDatasource.OpenSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.OpenSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2381,
)


_OPENSOURCEREPORT = _descriptor.Descriptor(
  name='OpenSourceReport',
  full_name='KismetDatasource.OpenSourceReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.OpenSourceReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dlt', full_name='KismetDatasource.OpenSourceReport.dlt', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capture_interface', full_name='KismetDatasource.OpenSourceReport.capture_interface', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.OpenSourceReport.channels', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.OpenSourceReport.channel', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hop_config', full_name='KismetDatasource.OpenSourceReport.hop_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.OpenSourceReport.hardware', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.OpenSourceReport.message', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.OpenSourceReport.spectrum', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KismetDatasource.OpenSourceReport.uuid', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.OpenSourceReport.warning', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2384,
  serialized_end=2780,
)


_PROBESOURCE = _descriptor.Descriptor(
  name='ProbeSource',
  full_name='KismetDatasource.ProbeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.ProbeSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2782,
  serialized_end=2815,
)


_PROBESOURCEREPORT = _descriptor.Descriptor(
  name='ProbeSourceReport',
  full_name='KismetDatasource.ProbeSourceReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ProbeSourceReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ProbeSourceReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.ProbeSourceReport.channels', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.ProbeSourceReport.channel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.ProbeSourceReport.spectrum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.ProbeSourceReport.hardware', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2818,
  serialized_end=3094,
)


_WARNINGREPORT = _descriptor.Descriptor(
  name='WarningReport',
  full_name='KismetDatasource.WarningReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.WarningReport.warning', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3096,
  serialized_end=3128,
)

_CONFIGURE.fields_by_name['channel'].message_type = _SUBCHANSET
_CONFIGURE.fields_by_name['hopping'].message_type = _SUBCHANHOP
_CONFIGURE.fields_by_name['spectrum'].message_type = _SUBSPECSET
_CONFIGUREREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_CONFIGUREREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_CONFIGUREREPORT.fields_by_name['hopping'].message_type = _SUBCHANHOP
_CONFIGUREREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_DATAREPORT.fields_by_name['gps'].message_type = _SUBGPS
_DATAREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_DATAREPORT.fields_by_name['packet'].message_type = _SUBPACKET
_DATAREPORT.fields_by_name['signal'].message_type = _SUBSIGNAL
_DATAREPORT.fields_by_name['spectrum'].message_type = _SUBSPECTRUM
_DATAREPORT.fields_by_name['json'].message_type = _SUBJSON
_DATAREPORT.fields_by_name['buffer'].message_type = _SUBBUFFER
_ERRORREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_ERRORREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_INTERFACESREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_INTERFACESREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_INTERFACESREPORT.fields_by_name['interfaces'].message_type = _SUBINTERFACE
_OPENSOURCEREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_OPENSOURCEREPORT.fields_by_name['channels'].message_type = _SUBCHANNELS
_OPENSOURCEREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_OPENSOURCEREPORT.fields_by_name['hop_config'].message_type = _SUBCHANHOP
_OPENSOURCEREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_OPENSOURCEREPORT.fields_by_name['spectrum'].message_type = _SUBSPECSET
_PROBESOURCEREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_PROBESOURCEREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_PROBESOURCEREPORT.fields_by_name['channels'].message_type = _SUBCHANNELS
_PROBESOURCEREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_PROBESOURCEREPORT.fields_by_name['spectrum'].message_type = _SUBSPECSET
DESCRIPTOR.message_types_by_name['SubChannels'] = _SUBCHANNELS
DESCRIPTOR.message_types_by_name['SubChanset'] = _SUBCHANSET
DESCRIPTOR.message_types_by_name['SubChanhop'] = _SUBCHANHOP
DESCRIPTOR.message_types_by_name['SubGps'] = _SUBGPS
DESCRIPTOR.message_types_by_name['SubInterface'] = _SUBINTERFACE
DESCRIPTOR.message_types_by_name['SubPacket'] = _SUBPACKET
DESCRIPTOR.message_types_by_name['SubJson'] = _SUBJSON
DESCRIPTOR.message_types_by_name['SubBuffer'] = _SUBBUFFER
DESCRIPTOR.message_types_by_name['SubSignal'] = _SUBSIGNAL
DESCRIPTOR.message_types_by_name['SubSpecset'] = _SUBSPECSET
DESCRIPTOR.message_types_by_name['SubSpectrum'] = _SUBSPECTRUM
DESCRIPTOR.message_types_by_name['SubSuccess'] = _SUBSUCCESS
DESCRIPTOR.message_types_by_name['CloseDatasource'] = _CLOSEDATASOURCE
DESCRIPTOR.message_types_by_name['Configure'] = _CONFIGURE
DESCRIPTOR.message_types_by_name['ConfigureReport'] = _CONFIGUREREPORT
DESCRIPTOR.message_types_by_name['DataReport'] = _DATAREPORT
DESCRIPTOR.message_types_by_name['ErrorReport'] = _ERRORREPORT
DESCRIPTOR.message_types_by_name['ListInterfaces'] = _LISTINTERFACES
DESCRIPTOR.message_types_by_name['InterfacesReport'] = _INTERFACESREPORT
DESCRIPTOR.message_types_by_name['NewSource'] = _NEWSOURCE
DESCRIPTOR.message_types_by_name['OpenSource'] = _OPENSOURCE
DESCRIPTOR.message_types_by_name['OpenSourceReport'] = _OPENSOURCEREPORT
DESCRIPTOR.message_types_by_name['ProbeSource'] = _PROBESOURCE
DESCRIPTOR.message_types_by_name['ProbeSourceReport'] = _PROBESOURCEREPORT
DESCRIPTOR.message_types_by_name['WarningReport'] = _WARNINGREPORT

SubChannels = _reflection.GeneratedProtocolMessageType('SubChannels', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANNELS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChannels)
  ))
_sym_db.RegisterMessage(SubChannels)

SubChanset = _reflection.GeneratedProtocolMessageType('SubChanset', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANSET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChanset)
  ))
_sym_db.RegisterMessage(SubChanset)

SubChanhop = _reflection.GeneratedProtocolMessageType('SubChanhop', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANHOP,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChanhop)
  ))
_sym_db.RegisterMessage(SubChanhop)

SubGps = _reflection.GeneratedProtocolMessageType('SubGps', (_message.Message,), dict(
  DESCRIPTOR = _SUBGPS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubGps)
  ))
_sym_db.RegisterMessage(SubGps)

SubInterface = _reflection.GeneratedProtocolMessageType('SubInterface', (_message.Message,), dict(
  DESCRIPTOR = _SUBINTERFACE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubInterface)
  ))
_sym_db.RegisterMessage(SubInterface)

SubPacket = _reflection.GeneratedProtocolMessageType('SubPacket', (_message.Message,), dict(
  DESCRIPTOR = _SUBPACKET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubPacket)
  ))
_sym_db.RegisterMessage(SubPacket)

SubJson = _reflection.GeneratedProtocolMessageType('SubJson', (_message.Message,), dict(
  DESCRIPTOR = _SUBJSON,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubJson)
  ))
_sym_db.RegisterMessage(SubJson)

SubBuffer = _reflection.GeneratedProtocolMessageType('SubBuffer', (_message.Message,), dict(
  DESCRIPTOR = _SUBBUFFER,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubBuffer)
  ))
_sym_db.RegisterMessage(SubBuffer)

SubSignal = _reflection.GeneratedProtocolMessageType('SubSignal', (_message.Message,), dict(
  DESCRIPTOR = _SUBSIGNAL,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSignal)
  ))
_sym_db.RegisterMessage(SubSignal)

SubSpecset = _reflection.GeneratedProtocolMessageType('SubSpecset', (_message.Message,), dict(
  DESCRIPTOR = _SUBSPECSET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSpecset)
  ))
_sym_db.RegisterMessage(SubSpecset)

SubSpectrum = _reflection.GeneratedProtocolMessageType('SubSpectrum', (_message.Message,), dict(
  DESCRIPTOR = _SUBSPECTRUM,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSpectrum)
  ))
_sym_db.RegisterMessage(SubSpectrum)

SubSuccess = _reflection.GeneratedProtocolMessageType('SubSuccess', (_message.Message,), dict(
  DESCRIPTOR = _SUBSUCCESS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSuccess)
  ))
_sym_db.RegisterMessage(SubSuccess)

CloseDatasource = _reflection.GeneratedProtocolMessageType('CloseDatasource', (_message.Message,), dict(
  DESCRIPTOR = _CLOSEDATASOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.CloseDatasource)
  ))
_sym_db.RegisterMessage(CloseDatasource)

Configure = _reflection.GeneratedProtocolMessageType('Configure', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGURE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.Configure)
  ))
_sym_db.RegisterMessage(Configure)

ConfigureReport = _reflection.GeneratedProtocolMessageType('ConfigureReport', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGUREREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ConfigureReport)
  ))
_sym_db.RegisterMessage(ConfigureReport)

DataReport = _reflection.GeneratedProtocolMessageType('DataReport', (_message.Message,), dict(
  DESCRIPTOR = _DATAREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.DataReport)
  ))
_sym_db.RegisterMessage(DataReport)

ErrorReport = _reflection.GeneratedProtocolMessageType('ErrorReport', (_message.Message,), dict(
  DESCRIPTOR = _ERRORREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ErrorReport)
  ))
_sym_db.RegisterMessage(ErrorReport)

ListInterfaces = _reflection.GeneratedProtocolMessageType('ListInterfaces', (_message.Message,), dict(
  DESCRIPTOR = _LISTINTERFACES,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ListInterfaces)
  ))
_sym_db.RegisterMessage(ListInterfaces)

InterfacesReport = _reflection.GeneratedProtocolMessageType('InterfacesReport', (_message.Message,), dict(
  DESCRIPTOR = _INTERFACESREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.InterfacesReport)
  ))
_sym_db.RegisterMessage(InterfacesReport)

NewSource = _reflection.GeneratedProtocolMessageType('NewSource', (_message.Message,), dict(
  DESCRIPTOR = _NEWSOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.NewSource)
  ))
_sym_db.RegisterMessage(NewSource)

OpenSource = _reflection.GeneratedProtocolMessageType('OpenSource', (_message.Message,), dict(
  DESCRIPTOR = _OPENSOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.OpenSource)
  ))
_sym_db.RegisterMessage(OpenSource)

OpenSourceReport = _reflection.GeneratedProtocolMessageType('OpenSourceReport', (_message.Message,), dict(
  DESCRIPTOR = _OPENSOURCEREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.OpenSourceReport)
  ))
_sym_db.RegisterMessage(OpenSourceReport)

ProbeSource = _reflection.GeneratedProtocolMessageType('ProbeSource', (_message.Message,), dict(
  DESCRIPTOR = _PROBESOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ProbeSource)
  ))
_sym_db.RegisterMessage(ProbeSource)

ProbeSourceReport = _reflection.GeneratedProtocolMessageType('ProbeSourceReport', (_message.Message,), dict(
  DESCRIPTOR = _PROBESOURCEREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ProbeSourceReport)
  ))
_sym_db.RegisterMessage(ProbeSourceReport)

WarningReport = _reflection.GeneratedProtocolMessageType('WarningReport', (_message.Message,), dict(
  DESCRIPTOR = _WARNINGREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.WarningReport)
  ))
_sym_db.RegisterMessage(WarningReport)


# @@protoc_insertion_point(module_scope)
