# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: http.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='http.proto',
  package='KismetExternalHttp',
  syntax='proto2',
  serialized_pb=_b('\n\nhttp.proto\x12\x12KismetExternalHttp\"\x16\n\x14HttpAuthTokenRequest\"\x1e\n\rHttpAuthToken\x12\r\n\x05token\x18\x01 \x02(\t\"N\n\x0fHttpRegisterUri\x12\x0b\n\x03uri\x18\x01 \x02(\t\x12\x0e\n\x06method\x18\x02 \x02(\t\x12\x1e\n\x16obsolete_auth_required\x18\x03 \x01(\x08\"5\n\x13SubHttpVariableData\x12\r\n\x05\x66ield\x18\x01 \x02(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x02(\t\"z\n\x0bHttpRequest\x12\x0e\n\x06req_id\x18\x01 \x02(\r\x12\x0b\n\x03uri\x18\x02 \x02(\t\x12\x0e\n\x06method\x18\x03 \x02(\t\x12>\n\rvariable_data\x18\x04 \x03(\x0b\x32\'.KismetExternalHttp.SubHttpVariableData\"#\n\x11HttpRequestCancel\x12\x0e\n\x06req_id\x18\x01 \x02(\r\"0\n\rSubHttpHeader\x12\x0e\n\x06header\x18\x01 \x02(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x02(\t\"\x96\x01\n\x0cHttpResponse\x12\x0e\n\x06req_id\x18\x01 \x02(\r\x12\x39\n\x0eheader_content\x18\x02 \x03(\x0b\x32!.KismetExternalHttp.SubHttpHeader\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nresultcode\x18\x04 \x01(\r\x12\x16\n\x0e\x63lose_response\x18\x05 \x01(\x08')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_HTTPAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='HttpAuthTokenRequest',
  full_name='KismetExternalHttp.HttpAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=56,
)


_HTTPAUTHTOKEN = _descriptor.Descriptor(
  name='HttpAuthToken',
  full_name='KismetExternalHttp.HttpAuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='KismetExternalHttp.HttpAuthToken.token', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=88,
)


_HTTPREGISTERURI = _descriptor.Descriptor(
  name='HttpRegisterUri',
  full_name='KismetExternalHttp.HttpRegisterUri',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='KismetExternalHttp.HttpRegisterUri.uri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='KismetExternalHttp.HttpRegisterUri.method', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='obsolete_auth_required', full_name='KismetExternalHttp.HttpRegisterUri.obsolete_auth_required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=168,
)


_SUBHTTPVARIABLEDATA = _descriptor.Descriptor(
  name='SubHttpVariableData',
  full_name='KismetExternalHttp.SubHttpVariableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='KismetExternalHttp.SubHttpVariableData.field', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.SubHttpVariableData.content', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=223,
)


_HTTPREQUEST = _descriptor.Descriptor(
  name='HttpRequest',
  full_name='KismetExternalHttp.HttpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpRequest.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uri', full_name='KismetExternalHttp.HttpRequest.uri', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='KismetExternalHttp.HttpRequest.method', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variable_data', full_name='KismetExternalHttp.HttpRequest.variable_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=347,
)


_HTTPREQUESTCANCEL = _descriptor.Descriptor(
  name='HttpRequestCancel',
  full_name='KismetExternalHttp.HttpRequestCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpRequestCancel.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=384,
)


_SUBHTTPHEADER = _descriptor.Descriptor(
  name='SubHttpHeader',
  full_name='KismetExternalHttp.SubHttpHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='KismetExternalHttp.SubHttpHeader.header', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.SubHttpHeader.content', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=434,
)


_HTTPRESPONSE = _descriptor.Descriptor(
  name='HttpResponse',
  full_name='KismetExternalHttp.HttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpResponse.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='header_content', full_name='KismetExternalHttp.HttpResponse.header_content', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.HttpResponse.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resultcode', full_name='KismetExternalHttp.HttpResponse.resultcode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='close_response', full_name='KismetExternalHttp.HttpResponse.close_response', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=587,
)

_HTTPREQUEST.fields_by_name['variable_data'].message_type = _SUBHTTPVARIABLEDATA
_HTTPRESPONSE.fields_by_name['header_content'].message_type = _SUBHTTPHEADER
DESCRIPTOR.message_types_by_name['HttpAuthTokenRequest'] = _HTTPAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['HttpAuthToken'] = _HTTPAUTHTOKEN
DESCRIPTOR.message_types_by_name['HttpRegisterUri'] = _HTTPREGISTERURI
DESCRIPTOR.message_types_by_name['SubHttpVariableData'] = _SUBHTTPVARIABLEDATA
DESCRIPTOR.message_types_by_name['HttpRequest'] = _HTTPREQUEST
DESCRIPTOR.message_types_by_name['HttpRequestCancel'] = _HTTPREQUESTCANCEL
DESCRIPTOR.message_types_by_name['SubHttpHeader'] = _SUBHTTPHEADER
DESCRIPTOR.message_types_by_name['HttpResponse'] = _HTTPRESPONSE

HttpAuthTokenRequest = _reflection.GeneratedProtocolMessageType('HttpAuthTokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _HTTPAUTHTOKENREQUEST,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpAuthTokenRequest)
  ))
_sym_db.RegisterMessage(HttpAuthTokenRequest)

HttpAuthToken = _reflection.GeneratedProtocolMessageType('HttpAuthToken', (_message.Message,), dict(
  DESCRIPTOR = _HTTPAUTHTOKEN,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpAuthToken)
  ))
_sym_db.RegisterMessage(HttpAuthToken)

HttpRegisterUri = _reflection.GeneratedProtocolMessageType('HttpRegisterUri', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREGISTERURI,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRegisterUri)
  ))
_sym_db.RegisterMessage(HttpRegisterUri)

SubHttpVariableData = _reflection.GeneratedProtocolMessageType('SubHttpVariableData', (_message.Message,), dict(
  DESCRIPTOR = _SUBHTTPVARIABLEDATA,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.SubHttpVariableData)
  ))
_sym_db.RegisterMessage(SubHttpVariableData)

HttpRequest = _reflection.GeneratedProtocolMessageType('HttpRequest', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREQUEST,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRequest)
  ))
_sym_db.RegisterMessage(HttpRequest)

HttpRequestCancel = _reflection.GeneratedProtocolMessageType('HttpRequestCancel', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREQUESTCANCEL,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRequestCancel)
  ))
_sym_db.RegisterMessage(HttpRequestCancel)

SubHttpHeader = _reflection.GeneratedProtocolMessageType('SubHttpHeader', (_message.Message,), dict(
  DESCRIPTOR = _SUBHTTPHEADER,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.SubHttpHeader)
  ))
_sym_db.RegisterMessage(SubHttpHeader)

HttpResponse = _reflection.GeneratedProtocolMessageType('HttpResponse', (_message.Message,), dict(
  DESCRIPTOR = _HTTPRESPONSE,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpResponse)
  ))
_sym_db.RegisterMessage(HttpResponse)


# @@protoc_insertion_point(module_scope)
