# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: linuxbluetooth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import kismet_pb2 as kismet__pb2
from . import datasource_pb2 as datasource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='linuxbluetooth.proto',
  package='KismetLinuxBluetooth',
  syntax='proto2',
  serialized_pb=_b('\n\x14linuxbluetooth.proto\x12\x14KismetLinuxBluetooth\x1a\x0ckismet.proto\x1a\x10\x64\x61tasource.proto\"\x8f\x01\n\x17SubLinuxBluetoothDevice\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x02(\t\x12\x0c\n\x04name\x18\x04 \x02(\t\x12\x0f\n\x07txpower\x18\x05 \x02(\x05\x12\x0c\n\x04type\x18\x06 \x02(\x05\x12\x11\n\tuuid_list\x18\x07 \x03(\t\"\xf0\x01\n\x18LinuxBluetoothDataReport\x12%\n\x03gps\x18\x01 \x01(\x0b\x32\x18.KismetDatasource.SubGps\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x0f\n\x07warning\x18\x03 \x01(\t\x12+\n\x06signal\x18\x04 \x01(\x0b\x32\x1b.KismetDatasource.SubSignal\x12?\n\x08\x62tdevice\x18\x05 \x02(\x0b\x32-.KismetLinuxBluetooth.SubLinuxBluetoothDevice')
  ,
  dependencies=[kismet__pb2.DESCRIPTOR,datasource__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SUBLINUXBLUETOOTHDEVICE = _descriptor.Descriptor(
  name='SubLinuxBluetoothDevice',
  full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.address', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.name', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='txpower', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.txpower', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.type', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid_list', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.uuid_list', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=222,
)


_LINUXBLUETOOTHDATAREPORT = _descriptor.Descriptor(
  name='LinuxBluetoothDataReport',
  full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gps', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.gps', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.warning', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='btdevice', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.btdevice', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=465,
)

_LINUXBLUETOOTHDATAREPORT.fields_by_name['gps'].message_type = datasource__pb2._SUBGPS
_LINUXBLUETOOTHDATAREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_LINUXBLUETOOTHDATAREPORT.fields_by_name['signal'].message_type = datasource__pb2._SUBSIGNAL
_LINUXBLUETOOTHDATAREPORT.fields_by_name['btdevice'].message_type = _SUBLINUXBLUETOOTHDEVICE
DESCRIPTOR.message_types_by_name['SubLinuxBluetoothDevice'] = _SUBLINUXBLUETOOTHDEVICE
DESCRIPTOR.message_types_by_name['LinuxBluetoothDataReport'] = _LINUXBLUETOOTHDATAREPORT

SubLinuxBluetoothDevice = _reflection.GeneratedProtocolMessageType('SubLinuxBluetoothDevice', (_message.Message,), dict(
  DESCRIPTOR = _SUBLINUXBLUETOOTHDEVICE,
  __module__ = 'linuxbluetooth_pb2'
  # @@protoc_insertion_point(class_scope:KismetLinuxBluetooth.SubLinuxBluetoothDevice)
  ))
_sym_db.RegisterMessage(SubLinuxBluetoothDevice)

LinuxBluetoothDataReport = _reflection.GeneratedProtocolMessageType('LinuxBluetoothDataReport', (_message.Message,), dict(
  DESCRIPTOR = _LINUXBLUETOOTHDATAREPORT,
  __module__ = 'linuxbluetooth_pb2'
  # @@protoc_insertion_point(class_scope:KismetLinuxBluetooth.LinuxBluetoothDataReport)
  ))
_sym_db.RegisterMessage(LinuxBluetoothDataReport)


# @@protoc_insertion_point(module_scope)
